# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class CreateEmbedJobRequestTruncate(str, enum.Enum):
    """
    One of `START|END` to specify how the API will handle inputs longer than the maximum token length.

    Passing `START` will discard the start of the input. `END` will discard the end of the input. In both cases, input is discarded until the remaining input is exactly the maximum input token length for the model.
    """

    START = "START"
    END = "END"

    def visit(self, start: typing.Callable[[], T_Result], end: typing.Callable[[], T_Result]) -> T_Result:
        if self is CreateEmbedJobRequestTruncate.START:
            return start()
        if self is CreateEmbedJobRequestTruncate.END:
            return end()
