# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClassifyResponseClassificationsItemClassificationType(str, enum.Enum):
    """
    The type of classification performed
    """

    SINGLE_LABEL = "single-label"
    MULTI_LABEL = "multi-label"

    def visit(
        self, single_label: typing.Callable[[], T_Result], multi_label: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is ClassifyResponseClassificationsItemClassificationType.SINGLE_LABEL:
            return single_label()
        if self is ClassifyResponseClassificationsItemClassificationType.MULTI_LABEL:
            return multi_label()
