# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SummarizeRequestFormat(str, enum.Enum):
    """
    One of `paragraph`, `bullets`, or `auto`, defaults to `auto`. Indicates the style in which the summary will be delivered - in a free form paragraph or in bullet points. If `auto` is selected, the best option will be picked based on the input text.
    """

    PARAGRAPH = "paragraph"
    BULLETS = "bullets"

    def visit(self, paragraph: typing.Callable[[], T_Result], bullets: typing.Callable[[], T_Result]) -> T_Result:
        if self is SummarizeRequestFormat.PARAGRAPH:
            return paragraph()
        if self is SummarizeRequestFormat.BULLETS:
            return bullets()
