# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class EmbedJobTruncate(str, enum.Enum):
    """
    The truncation option used
    """

    START = "START"
    END = "END"

    def visit(self, start: typing.Callable[[], T_Result], end: typing.Callable[[], T_Result]) -> T_Result:
        if self is EmbedJobTruncate.START:
            return start()
        if self is EmbedJobTruncate.END:
            return end()
