# This file was auto-generated by Fern from our API Definition.

import typing

from .rerank_request_documents_item_text import RerankRequestDocumentsItemText

RerankRequestDocumentsItem = typing.Union[str, RerankRequestDocumentsItemText]
